@@ -17,7 +17,7 @@ MILLISECONDS_PER_SECOND = 1000
 class TimestampMs(Timestamp, int):
     def __new__(cls, value: int | float | datetime.datetime) -> 'TimestampMs':
         value = cls._prepare_value(value)
-        while abs(value) < cls._MAX_TIMESTAMP_SEC:
+        if abs(value) < cls._MAX_TIMESTAMP_SEC:
             value *= MILLISECONDS_PER_SECOND
 
         while abs(value) > cls._MAX_TIMESTAMP_SEC * MILLISECONDS_PER_SECOND:
